==> jc-1.4.0.tar.gz: javax/swing/JColorChooser__24DefaultResetListener.h <==
// class javax.swing.JColorChooser$DefaultResetListener

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a3b15414c80c0301 javax_swing_JColorChooser__24DefaultResetListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_JColorChooser__24DefaultResetListener_H_
#define _JC_javax_swing_JColorChooser__24DefaultResetListener_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JColorChooser$object;

// Typedefs
typedef struct _jc_javax_swing_JColorChooser__24DefaultResetListener$sub_refs	_jc_javax_swing_JColorChooser__24DefaultResetListener$sub_refs;
typedef struct _jc_javax_swing_JColorChooser__24DefaultResetListener$sub_nonrefs	_jc_javax_swing_JColorChooser__24DefaultResetListener$sub_nonrefs;
typedef struct _jc_javax_swing_JColorChooser__24DefaultResetListener$refs	_jc_javax_swing_JColorChooser__24DefaultResetListener$refs;
typedef struct _jc_javax_swing_JColorChooser__24DefaultResetListener$nonrefs	_jc_javax_swing_JColorChooser__24DefaultResetListener$nonrefs;
typedef struct _jc_javax_swing_JColorChooser__24DefaultResetListener$object	_jc_javax_swing_JColorChooser__24DefaultResetListener$object;

typedef const struct _jc_javax_swing_JColorChooser__24DefaultResetListener$vmethods	_jc_javax_swing_JColorChooser__24DefaultResetListener$vmethods;
typedef const struct _jc_javax_swing_JColorChooser__24DefaultResetListener$vtable	_jc_javax_swing_JColorChooser__24DefaultResetListener$vtable;
typedef const struct _jc_javax_swing_JColorChooser__24DefaultResetListener$vtype	_jc_javax_swing_JColorChooser__24DefaultResetListener$vtype;

// Constructors
extern void _jc_javax_swing_JColorChooser__24DefaultResetListener$method$_init$8f26f12d11073619(_jc_env *, struct _jc_javax_swing_JColorChooser__24DefaultResetListener$object *, struct _jc_javax_swing_JColorChooser$object *);

// Virtual methods
extern void _jc_javax_swing_JColorChooser__24DefaultResetListener$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_JColorChooser__24DefaultResetListener$object *, struct _jc_java_awt_event_ActionEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JColorChooser__24DefaultResetListener$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_JColorChooser__24DefaultResetListener$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_JColorChooser__24DefaultResetListener$object *, struct _jc_java_awt_event_ActionEvent$object *);
};

// Vtable
struct _jc_javax_swing_JColorChooser__24DefaultResetListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_JColorChooser__24DefaultResetListener$vmethods	javax_swing_JColorChooser__24DefaultResetListener;
};

// Vtype
struct _jc_javax_swing_JColorChooser__24DefaultResetListener$vtype {
	_jc_type			type;
	_jc_javax_swing_JColorChooser__24DefaultResetListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JColorChooser__24DefaultResetListener$sub_refs {
	struct _jc_javax_swing_JColorChooser$object	*chooser;
	struct _jc_java_awt_Color$object	*init;
};

// Reference instance fields (object)
struct _jc_javax_swing_JColorChooser__24DefaultResetListener$refs {
    _jc_javax_swing_JColorChooser__24DefaultResetListener$sub_refs	javax_swing_JColorChooser__24DefaultResetListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JColorChooser__24DefaultResetListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JColorChooser__24DefaultResetListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_JColorChooser__24DefaultResetListener$sub_nonrefs	javax_swing_JColorChooser__24DefaultResetListener;
};

// Object instance structure
struct _jc_javax_swing_JColorChooser__24DefaultResetListener$object {
	_jc_javax_swing_JColorChooser__24DefaultResetListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JColorChooser__24DefaultResetListener$vtype	*vtype;
	_jc_javax_swing_JColorChooser__24DefaultResetListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JColorChooser__24DefaultResetListener$vtype _jc_javax_swing_JColorChooser__24DefaultResetListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JColorChooser__24DefaultResetListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JColorChooser__24DefaultResetListener$class_object;

#endif	/* _JC_javax_swing_JColorChooser__24DefaultResetListener_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JColorChooser__24DefaultResetListener.h <==
// class javax.swing.JColorChooser$DefaultResetListener

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a3b15414c80c0301 javax_swing_JColorChooser__24DefaultResetListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_JColorChooser__24DefaultResetListener_H_
#define _JC_javax_swing_JColorChooser__24DefaultResetListener_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_event_ActionEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JColorChooser$object;

// Typedefs
typedef struct _jc_javax_swing_JColorChooser__24DefaultResetListener$sub_refs	_jc_javax_swing_JColorChooser__24DefaultResetListener$sub_refs;
typedef struct _jc_javax_swing_JColorChooser__24DefaultResetListener$sub_nonrefs	_jc_javax_swing_JColorChooser__24DefaultResetListener$sub_nonrefs;
typedef struct _jc_javax_swing_JColorChooser__24DefaultResetListener$refs	_jc_javax_swing_JColorChooser__24DefaultResetListener$refs;
typedef struct _jc_javax_swing_JColorChooser__24DefaultResetListener$nonrefs	_jc_javax_swing_JColorChooser__24DefaultResetListener$nonrefs;
typedef struct _jc_javax_swing_JColorChooser__24DefaultResetListener$object	_jc_javax_swing_JColorChooser__24DefaultResetListener$object;

typedef const struct _jc_javax_swing_JColorChooser__24DefaultResetListener$vmethods	_jc_javax_swing_JColorChooser__24DefaultResetListener$vmethods;
typedef const struct _jc_javax_swing_JColorChooser__24DefaultResetListener$vtable	_jc_javax_swing_JColorChooser__24DefaultResetListener$vtable;
typedef const struct _jc_javax_swing_JColorChooser__24DefaultResetListener$vtype	_jc_javax_swing_JColorChooser__24DefaultResetListener$vtype;

// Constructors
extern void _jc_javax_swing_JColorChooser__24DefaultResetListener$method$_init$8f26f12d11073619(_jc_env *, struct _jc_javax_swing_JColorChooser__24DefaultResetListener$object *, struct _jc_javax_swing_JColorChooser$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_JColorChooser__24DefaultResetListener$method$actionPerformed$9046a9754e643ffd(_jc_env *, struct _jc_javax_swing_JColorChooser__24DefaultResetListener$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JColorChooser__24DefaultResetListener$method_info$actionPerformed$9046a9754e643ffd;

// Virtual methods structure
struct _jc_javax_swing_JColorChooser__24DefaultResetListener$vmethods {
	void	(*actionPerformed$9046a9754e643ffd)(_jc_env *, struct _jc_javax_swing_JColorChooser__24DefaultResetListener$object *, struct _jc_java_awt_event_ActionEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JColorChooser__24DefaultResetListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_JColorChooser__24DefaultResetListener$vmethods	javax_swing_JColorChooser__24DefaultResetListener;
};

// Vtype
struct _jc_javax_swing_JColorChooser__24DefaultResetListener$vtype {
	_jc_type			type;
	_jc_javax_swing_JColorChooser__24DefaultResetListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JColorChooser__24DefaultResetListener$sub_refs {
	struct _jc_javax_swing_JColorChooser$object	*chooser;
	struct _jc_java_awt_Color$object	*init;
};

// Reference instance fields (object)
struct _jc_javax_swing_JColorChooser__24DefaultResetListener$refs {
    _jc_javax_swing_JColorChooser__24DefaultResetListener$sub_refs	javax_swing_JColorChooser__24DefaultResetListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JColorChooser__24DefaultResetListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JColorChooser__24DefaultResetListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_JColorChooser__24DefaultResetListener$sub_nonrefs	javax_swing_JColorChooser__24DefaultResetListener;
};

// Object instance structure
struct _jc_javax_swing_JColorChooser__24DefaultResetListener$object {
	_jc_javax_swing_JColorChooser__24DefaultResetListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JColorChooser__24DefaultResetListener$vtype	*vtype;
	_jc_javax_swing_JColorChooser__24DefaultResetListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JColorChooser__24DefaultResetListener$vtype _jc_javax_swing_JColorChooser__24DefaultResetListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JColorChooser__24DefaultResetListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JColorChooser__24DefaultResetListener$class_object;

#endif	/* _JC_javax_swing_JColorChooser__24DefaultResetListener_H_ */
